Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/matomo-org/matomo.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'core/API/Request.php')
-rw-r--r--core/API/Request.php5
1 files changed, 3 insertions, 2 deletions
diff --git a/core/API/Request.php b/core/API/Request.php
index 4af8db7500..7a7569e59c 100644
--- a/core/API/Request.php
+++ b/core/API/Request.php
@@ -11,6 +11,7 @@
use Piwik\Piwik;
use Piwik\Common;
use Piwik\Access;
+use Piwik\DataTable;
/**
* An API request is the object used to make a call to the API and get the result.
@@ -121,7 +122,7 @@ class Piwik_API_Request
* It then calls the API Proxy which will call the requested method.
*
* @throws Piwik_FrontController_PluginDeactivatedException
* @return Piwik_DataTable|mixed The data resulting from the API call
*/
public function process()
{
@@ -137,7 +138,7 @@ class Piwik_API_Request
list($module, $method) = $this->extractModuleAndMethod($moduleMethod);
- if (!PluginsManager::getInstance()->isPluginActivated($module)) {
+ if (!\Piwik\PluginsManager::getInstance()->isPluginActivated($module)) {
throw new Piwik_FrontController_PluginDeactivatedException($module);
}
$moduleClass = "Piwik_" . $module . "_API";
@@ -121,7 +122,7 @@ class Piwik_API_Request
*
* @throws Piwik_FrontController_PluginDeactivatedException
- * @return Piwik_DataTable|mixed The data resulting from the API call
+ * @return DataTable|mixed The data resulting from the API call
*/
public function process()